@@ -23,8 +23,7 @@ mod filepatterns;
 pub mod matchers;
 pub mod revlog;
 pub use revlog::*;
-#[cfg(feature = "with-re2")]
-pub mod re2;
+pub mod operations;
 pub mod utils;
 
 // Remove this to see (potential) non-artificial compile failures. MacOS
@@ -141,9 +140,6 @@ pub enum PatternError {
     /// Needed a pattern that can be turned into a regex but got one that
     /// can't. This should only happen through programmer error.
     NonRegexPattern(IgnorePattern),
-    /// This is temporary, see `re2/mod.rs`.
-    /// This will cause a fallback to Python.
-    Re2NotInstalled,
 }
 
 impl ToString for PatternError {
@@ -166,10 +162,6 @@ impl ToString for PatternError {
             PatternError::NonRegexPattern(pattern) => {
                 format!("'{:?}' cannot be turned into a regex", pattern)
             }
-            PatternError::Re2NotInstalled => {
-                "Re2 is not installed, cannot use regex functionality."
-                    .to_string()
-            }
         }
     }
 }
